import{l as m,N as l,a8 as c,c as u,v as h,B as f,j as w,I as a,J as b}from"./index-e5db0b73.js";import{_ as d}from"./ItemsListing.vue_vue_type_style_index_0_lang-6fa46e09.js";import"./ListviewItem-7c178b7a.js";import"./VBadge-efd00f67.js";import"./ListItem-ac3869d3.js";import"./VImg-7a057c50.js";import"./VMenu-d9833a31.js";import"./VCheckboxBtn-46446b67.js";import"./VCard-c9b9f4e9.js";import"./VTooltip-71530943.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-221d4edc.js";import"./contextmenu-8eac6b44.js";import"./Alert-1172b8fb.js";import"./Container-238e2d02.js";import"./VToolbar-4e8dded4.js";import"./VTextField-46667b30.js";import"./VVirtualScroll-01555b84.js";const z=m({__name:"BrowseView",props:{path:{}},setup(s){const t=s,{t:e}=l();c();const p=u(()=>!t.path||t.path=="root"?e("browse"):a("bp6")?e("browse")+" | "+t.path:a("bp3")?t.path:e("browse")),i=async function(r){const o=[];return await b.browse(t.path,n=>{o.push(...n)}),o};return(r,o)=>(h(),f("section",null,[w(d,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":i,"sort-keys":["original","name","name_desc"],title:p.value,path:r.path,"allow-key-hooks":!0},null,8,["title","path"])]))}});export{z as default};
