.home-card{min-width:80px;text-align:center;padding-top:12px;padding-bottom:8px}.widget-row{margin-bottom:20px}.v-slide-group__prev{min-width:0px!important;margin-right:-15px}.v-slide-group__next{min-width:0px!important}
